===================
ECS Compose-X Specs
===================


.. image:: https://img.shields.io/pypi/v/ecs_composex_specs.svg
        :target: https://pypi.python.org/pypi/ecs_composex_specs

.. image:: https://readthedocs.org/projects/compose-x-specs/badge/?version=latest
        :target: https://compose-x-specs.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status


Specifications for ECS Compose-X.


* Free software: MPL2.0
* Documentation: https://ecs-composex-specs.readthedocs.io.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
